==> sleet-1.0.3-py3-none-any.whl: sleet/blizzardapi.py <==
"""
This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0.
If a copy of the MPL was not distributed with this file, You can obtain one at https://mozilla.org/MPL/2.0/.
"""

import os
from typing import Optional

from sleet.constants import WarcraftExpansion
from sleet.diablo3 import Diablo3API
from sleet.exceptions import CredentialError
from sleet.hearthstone import HearthstoneAPI
from sleet.warcraft import WarcraftAPI


class BlizzardAPI:
    def __init__(self, api_region: str, *, api_id: Optional[str] = None, api_secret: Optional[str] = None):
        api_id = api_id or os.getenv("BNET_API_ID")
        api_secret = api_secret or os.getenv("BNET_API_SECRET")

        if not api_id:
            raise CredentialError("BNET_API_ID environment variable must be present or client_id "
                                  "argument must be set.")

        if not api_secret:
            raise CredentialError("BNET_API_SECRET environment variable must be present or client_secret "
                                  "argument must be set.")

        self.diablo3 = Diablo3API(
            api_region=api_region,
            api_id=api_id,
            api_secret=api_secret)
        self.hearthstone = HearthstoneAPI(
            api_region=api_region,
            api_id=api_id,
            api_secret=api_secret)
        self.wow = WarcraftAPI(
            api_region=api_region,
            api_id=api_id,
            api_secret=api_secret,
            expansion=WarcraftExpansion.RETAIL)
        self.wow_classic = WarcraftAPI(
            api_region=api_region,
            api_id=api_id,
            api_secret=api_secret,
            expansion=WarcraftExpansion.CLASSIC)
        self.wow_tbcc = WarcraftAPI(
            api_region=api_region,
            api_id=api_id,
            api_secret=api_secret,
            expansion=WarcraftExpansion.TBCC)

==> sleet-1.1.1-py3-none-any.whl: sleet/blizzardapi.py <==
"""
This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0.
If a copy of the MPL was not distributed with this file, You can obtain one at https://mozilla.org/MPL/2.0/.
"""

import os
from typing import Optional

from sleet.constants import WarcraftExpansion
from sleet.diablo3 import Diablo3API
from sleet.exceptions import CredentialError
from sleet.hearthstone import HearthstoneAPI
from sleet.warcraft import WarcraftAPI


class BlizzardAPI:
    def __init__(self, api_region: str, *, api_id: Optional[str] = None, api_secret: Optional[str] = None):
        api_id = api_id or os.getenv("BNET_API_ID")
        api_secret = api_secret or os.getenv("BNET_API_SECRET")

        if not api_id:
            raise CredentialError("BNET_API_ID environment variable must be present or "
                                  "api_id argument must be set.")

        if not api_secret:
            raise CredentialError("BNET_API_SECRET environment variable must be present or "
                                  "api_secret argument must be set.")

        self.diablo3 = Diablo3API(
            api_region=api_region,
            api_id=api_id,
            api_secret=api_secret)
        self.hearthstone = HearthstoneAPI(
            api_region=api_region,
            api_id=api_id,
            api_secret=api_secret)
        self.wow = WarcraftAPI(
            api_region=api_region,
            api_id=api_id,
            api_secret=api_secret,
            expansion=WarcraftExpansion.RETAIL)
        self.wow_classic = WarcraftAPI(
            api_region=api_region,
            api_id=api_id,
            api_secret=api_secret,
            expansion=WarcraftExpansion.CLASSIC)
        self.wow_tbcc = WarcraftAPI(
            api_region=api_region,
            api_id=api_id,
            api_secret=api_secret,
            expansion=WarcraftExpansion.TBCC)
